#GIT_CMT=22ae11c8d648b0946e477957f11f0c49fa48abbb
# Copyright(c) 2015, Oracle and/or its affiliates.  All Rights Reserved.
#
#    Licensed under the Apache License, Version 2.0 (the "License"); you may
#    not use this file except in compliance with the License. You may obtain
#    a copy of the License at
#
#         http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#    License for the specific language governing permissions and limitations
#    under the License.

# Python major version.
%{expand: %%define pyver %(python -c 'import sys;print(sys.version[0:3])')}

# Package version
%global package_version 3.0.1

# Kolla user name and group name (DO NOT CHANGE THESE!)
%global kolla_user      kolla
%global kolla_group     %{kolla_user}

# kolla ansible plugin related vars
%global plugin_dir      %{_datadir}/ansible/plugins/callback
%global plugin_name     kolla_callback

Summary:        OpenStack Kolla CLI
Name:           openstack-kollacli
Version:        %{package_version}
Release:    54.el7
License:        Apache License, Version 2.0
Group:          Applications/System
Url:            https://launchpad.net/kolla
Source0: openstack-kollacli-3.0.1.tar.bz2
BuildArch:      noarch
BuildRequires:  python                      >= 2.7
BuildRequires:  python-setuptools           >= 0.9.8
BuildRequires:  python-pbr                  >= 1.3.0
Requires:       openstack-kolla-ansible-plugin >= 3.0.0
Requires:       babel                       >= 2.0
Requires:       python-babel                >= 2.0
Requires:       python-cliff                >= 1.13.0
Requires:       python-cliff-tablib         >= 1.1
Requires:       python-jsonpickle           >= 0.9.2
Requires:       python-oslo-i18n            >= 2.5.0
Requires:       python-paramiko             >= 1.15.1
Requires:       python-pbr                  >= 1.6.0
Requires:       python-six                  >= 1.9.0
Requires:       PyYAML                      >= 3.10

Requires:       /usr/bin/ssh-keygen

%description
The KollaCLI simplifies OpenStack Kolla deployments.

%prep
%setup -q -n %{name}-%{version}

%build
# Generate a temporary pkg-info file to make pbr happy
PKGINFO_NAME=$(sed -n -e '/^name/ s/name\s=\s//p' setup.cfg)
PKGINFO_VERSION=$(sed -n -e '/^version/ s/version\s=\s//p' setup.cfg)
cat >PKG-INFO <<__EOF__
Metadata-Version: 1.1
Name: ${PKGINFO_NAME}
Version: ${PKGINFO_VERSION}
__EOF__

# Build the package
%{__python} setup.py build


%install
# Install the package
%{__python} setup.py install --skip-build --root %{buildroot}

# Create the required directory structures
mkdir -m 0755 -p %{buildroot}/%{_sysconfdir}/kolla/kollacli
mkdir -m 0775 -p %{buildroot}/%{_sysconfdir}/kolla/kollacli/ansible
mkdir -m 0750 -p %{buildroot}/%{_datadir}/kolla/kollacli/tools
mkdir -m 0755 -p %{buildroot}/%{_datadir}/kolla/ansible

cat >%{buildroot}/%{_datadir}/kolla/kollacli/LICENSE.TXT <<EOF
Oracle OpenStack for Oracle Linux is a management software package
comprised of various OpenStack components combined with independent software
programs that operate as OpenStack services. These independent programs
include parts of MySQL Community Edition, Oracle Linux and MySQL Cluster
Community Edition. The license for each OpenStack component, as well as the
licenses for each independent program, can be found in the root folder for
each component and/or program or in the specific Docker Container or RPM
package.
EOF

# Create a kolla log directory
mkdir -m 0770 -p %{buildroot}/%{_var}/log/kolla

# Install the required OpenStack Kolla files
cp -r tools/* %{buildroot}/%{_datadir}/kolla/kollacli/tools
cp -r openstack-kolla-data/ansible.cfg %{buildroot}/%{_datadir}/kolla/.ansible.cfg
cp -r openstack-kolla-data/ansible/prechecks_preinstall.yml %{buildroot}/%{_datadir}/kolla/ansible/prechecks_preinstall.yml

# Create an empty inventory file
touch %{buildroot}/%{_sysconfdir}/kolla/kollacli/ansible/inventory.json
chmod 0664 %{buildroot}/%{_sysconfdir}/kolla/kollacli/ansible/inventory.json

# copy over plugin
mkdir -p %{buildroot}/%{plugin_dir}
cp -r ansible_plugins/%{plugin_name}.py %{buildroot}/%{plugin_dir}/

%clean
rm -rf %{buildroot}


%files
%defattr(-, %{kolla_user}, %{kolla_group})
%attr(-, root, root) %doc LICENSE
%attr(-, root, root) %{python_sitelib}
%attr(755, root, %{kolla_group}) %{_bindir}/kollacli
%attr(550, %{kolla_user}, %{kolla_group}) %dir %{_datadir}/kolla/kollacli/tools
%attr(500, %{kolla_user}, %{kolla_group}) %{_datadir}/kolla/kollacli/tools/kolla_actions*
%attr(550, %{kolla_user}, %{kolla_group}) %{_datadir}/kolla/kollacli/tools/log_*
%attr(-, %{kolla_user}, %{kolla_group}) %config(noreplace) %{_sysconfdir}/kolla/kollacli
%attr(2770, %{kolla_user}, %{kolla_group}) %dir %{_var}/log/kolla
%attr(644, %{kolla_user}, %{kolla_group}) %{_datadir}/kolla/ansible/prechecks_preinstall.yml
%{_datadir}/kolla/kollacli/LICENSE.TXT

%pre
case "$*" in
    0)
        #
        # Install package
        #
        inst_type="install"
        ;;
    *)
        #
        # Update package
        #
        inst_type="update"
        ;;
esac

if [[ "${inst_type}" == "update" ]]
then
    rm -rf %{python_sitelib}/kollacli-*egg-info 2> /dev/null
fi

%post
setfacl -m d:g:%{kolla_group}:rw %{_var}/log/kolla

if ! test -f %{_datadir}/kolla/kollacli/ansible.lock
then
    touch %{_datadir}/kolla/kollacli/ansible.lock
    chown %{kolla_user}:%{kolla_group} %{_datadir}/kolla/kollacli/ansible.lock
    chmod 0660 %{_datadir}/kolla/kollacli/ansible.lock
fi

if ! test -f ~%{kolla_user}/.ssh/id_rsa
then
    runuser -m -s /bin/bash -c \
        "/usr/bin/ssh-keygen -q -t rsa -N '' -f ~%{kolla_user}/.ssh/id_rsa" \
        %{kolla_user}
fi

# always copy the key over, in case it was re-created in kolla/.ssh
cp -p ~%{kolla_user}/.ssh/id_rsa.pub %{_sysconfdir}/kolla/kollacli/id_rsa.pub
chmod 0440 %{_sysconfdir}/kolla/kollacli/id_rsa.pub

/usr/bin/kollacli complete >%{_sysconfdir}/bash_completion.d/kollacli 2>/dev/null

# Update the sudoers file
if ! grep -q 'kollacli/tools/kolla_actions' %{_sysconfdir}/sudoers.d/%{kolla_user}
then
    sed -i \
        '/^Cmnd_Alias.*KOLLA_CMDS/ s:$:, %{_datadir}/kolla/kollacli/tools/kolla_actions.py:'\
        %{_sysconfdir}/sudoers.d/%{kolla_user}
fi
# remove obsolete password editor from sudoers file
sed -i \
    '/^Cmnd_Alias.*KOLLA_CMDS/ s:, %{_datadir}/kolla/kollacli/tools/passwd_editor.py::'\
     %{_sysconfdir}/sudoers.d/%{kolla_user}

# add version property for prechecks_preinstall.yml playbook
if ! grep -q 'kolla_preinstall_version' %{_datadir}/kolla/ansible/group_vars/__GLOBAL__
# property doesn't yet exist
then
    cat >> %{_datadir}/kolla/ansible/group_vars/__GLOBAL__ << EOF

kolla_preinstall_version: "%{package_version}"
EOF
elif ! grep -q 'kolla_preinstall_version: "%{package_version}"' %{_datadir}/kolla/ansible/group_vars/__GLOBAL__
# property exists but at wrong version, need to update it
then
    sed -i \
    's/^kolla_preinstall_version.*$/kolla_preinstall_version: "%{package_version}"/' \
     %{_datadir}/kolla/ansible/group_vars/__GLOBAL__
fi

%postun
case "$*" in
    0)
        rm -f %{_sysconfdir}/bash_completion.d/kollacli
        rm -rf %{_datadir}/kolla/kollacli
    ;;
    *)
        ## Nothing for update
    ;;
esac


# kolla ansible plugin rpm specific work
%package -n openstack-kolla-ansible-plugin

Summary:        OpenStack Kolla Ansible Plugin
Version:        %{package_version}
License:        GNU General Public License, Version 3
Group:          Applications/System
# The plugin needs ansible 2.1 which is in the
# requirement for openstack-kolla-ansible
Requires:       openstack-kolla-ansible     >= 3.0.0
Requires:       openstack-kolla-ansible     < 4.0.0

%description -n openstack-kolla-ansible-plugin
This ansible plugin supplies playbook activity to the
openstack-kollacli client.

%files -n openstack-kolla-ansible-plugin
%defattr(-, %{kolla_user}, %{kolla_group})
%attr(-, root, root) %doc ansible_plugins/LICENSE
%attr(755, %{kolla_user}, %{kolla_group}) %{plugin_dir}/*
%attr(644, %{kolla_user}, %{kolla_group}) %{_datadir}/kolla/.ansible.cfg

%changelog
* Fri Mar 17 2017 Borne Mace <borne.mace@oracle.com> - 3.0.1-54.el7
- BUILDINFO: commit=22ae11c8d648b0946e477957f11f0c49fa48abbb
- Added required LICENSE.TXT (Borne Mace)  

* Wed Dec 14 2016 Borne Mace <borne.mace@oracle.com> - 3.0.1-53.el7
- BUILDINFO: commit=e4f52da6c960a65b2c08fa05456a2e92e8c3d563
- Revert "Added support for a new reconfigure command" (Borne Mace)

* Tue Dec 13 2016 Borne Mace <borne.mace@oracle.com> - 3.0.1-52.el7
- BUILDINFO: commit=3c4828e10850618e2ca8e721aa1f5450b0eeebc6
- Added support for a new reconfigure command (Borne Mace)

* Tue Nov 15 2016 Borne Mace <borne.mace@oracle.com> - 3.0.1-51.el7
- BUILDINFO: commit=5dc9de9cf61b580d827e601e39cbcb1161d55a3a
- Modified per host commands to use ansible --limit (Borne Mace)

* Fri Nov 04 2016 Borne Mace <borne.mace@oracle.com> - 3.0.1-50.el7
- BUILDINFO: commit=f7166ed61c7d2915ea15da88600d6deb313cee92
- API support for the reconfigure action (Borne Mace)

* Wed Nov 02 2016 Borne Mace <borne.mace@oracle.com> - 3.0.1-49.el7
- BUILDINFO: commit=3e5cc35f4b7bd306f003c0670a5a693187456b1d
- Added support for turning off locking with environment variable (Borne Mace)

* Wed Nov 02 2016 Borne Mace <borne.mace@oracle.com> - 3.0.1-48.el7
- BUILDINFO: commit=bc42e6b13ed44b5c81897ec84523f69da6a89373
- WIP: Added initial support for stop containers (Borne Mace)

* Tue Nov 01 2016 Borne Mace <borne.mace@oracle.com> - 3.0.1-47.el7
- BUILDINFO: commit=0c56e5792d476d83f3d0a0c013ec01bd03e73dc3
- Fixed bug causing destroy on multiple hosts to fail (Borne Mace)

* Mon Oct 31 2016 Borne Mace <borne.mace@oracle.com> - 3.0.1-46.el7
- BUILDINFO: commit=7cbb157082b23502fba3268195a1655822afb443
- Pass through unlimited -v args to ansible playbook (Borne Mace)

* Thu Oct 27 2016 Borne Mace <borne.mace@oracle.com> - 3.0.1-45.el7
- BUILDINFO: commit=a3204506fefc11314e1662f33900d4b8d909096e
- Added support for ignoring certain ansible errors. (Borne Mace)

* Tue Oct 25 2016 Borne Mace <borne.mace@oracle.com> - 3.0.1-44.el7
- BUILDINFO: commit=4c70581528ee2057d693ac422f83431ac8b0e2a8
- Fixed rpm spec after removal of the custom cli destroy playbooks (Borne Mace)  
- Removed no longer relevant cli destroy playbooks (Borne Mace)

* Fri Oct 21 2016 Borne Mace <borne.mace@oracle.com> - 3.0.1-43.el7
- BUILDINFO: commit=9772b1ab282fc61e2ff663c482e2ecd3f98629cc
- Added support for removal of docker images during destroy (Borne Mace)

* Thu Oct 13 2016 Steve Noyes <steve.noyes@oracle.com> - 3.0.1-42.el7
- BUILDINFO: commit=55da56990d4f5bac523f307f0090149e7baaa10a
- allow empty passwords to be set (Steve Noyes)

* Wed Oct 12 2016 Borne Mace <borne.mace@oracle.com> - 3.0.1-41.el7
- BUILDINFO: commit=31363f88770c24de25aa382b55df02926664ba60
- Updated destroy to use upstream destroy playbook (Borne Mace)

* Wed Oct 12 2016 Steve Noyes <steve.noyes@oracle.com> - 3.0.1-40.el7
- BUILDINFO: commit=bb16c06c95ac8067883ddc0b240d8b4f42fc4f85
- support multiple parents of services in allinone file (Steve Noyes)

* Tue Oct 11 2016 Vladislav Belogrudov <vladislav.belogrudov@oracle.com> - 3.0.1-39.el7
- BUILDINFO: commit=3ad1c68770dd6a462478f9f6861673a0b3c13dea
- Allow empty groups and comments (Vladislav Belogrudov)

* Tue Oct 11 2016 James McCarthy <james.m.mccarthy@oracle.com> - 3.0.1-38.el7
- BUILDINFO: commit=28a9d9331d8138fedc5c7c92ad91b3c5393cd89b
- Adjust preinstall entry to include a blank line. (James McCarthy)

* Fri Oct 07 2016 Steve Noyes <steve.noyes@oracle.com> - 3.0.1-37.el7
- BUILDINFO: commit=8d87beaa59a469bbc1f9667f006292d16720ebc6
- use cat command to add kolla_preinstall_version to properties file (Steve Noyes)

* Wed Oct 05 2016 Borne Mace <borne.mace@oracle.com> - 3.0.1-36.el7
- BUILDINFO: commit=ol7/openstack-kollacli-3.0.1-36
- Added support for upgrade and deploy per service (Borne Mace)  
- Update api docs (Steve Noyes)

* Thu Sep 22 2016 Steve Noyes <steve.noyes@oracle.com> - 3.0.1-34.el7
- add new cli/api command to init passwords (Steve Noyes)

* Wed Sep 21 2016 Steve Noyes <steve.noyes@oracle.com> - 3.0.1-33.el7
- add kolla_preinstall_version property in rpm spec (Steve Noyes)  
- clear out all /usr/share/kolla/kollacli files on uninstall (Steve Noyes)  
- add ability to cli/api to add/clear ssh keys in password file (Steve Noyes)

* Mon Sep 19 2016 Steve Noyes <steve.noyes@oracle.com> - 3.0.1-31.el7
- move oracle-specific precheck to kollacli rpm (Steve Noyes)

* Fri Sep 16 2016 Steve Noyes <steve.noyes@oracle.com> - 3.0.1-30.el7
- add empty password check on deploy (Steve Noyes)  
- remove docker-py requirement from kollacli (Steve Noyes)  
- unit test updates for mitaka changes (Steve Noyes)

* Tue Sep 13 2016 Steve Noyes <steve.noyes@oracle.com> - 3.0.1-29.el7
- use inventory_samples as name of all-in-one dir (Steve Noyes)

* Mon Sep 12 2016 Steve Noyes <steve.noyes@oracle.com> - 3.0.1-28.el7
- add ansible.cfg to kollacli spec (Steve Noyes)  
- in api, avoid adding keys if host is already setup (Steve Noyes)  
- Changed initial inventory generation source path (Borne Mace)

* Thu Sep 08 2016 Steve Noyes <steve.noyes@oracle.com> - 3.0.1-27.el7
- ensure dir for temp inventory is writable (Steve Noyes)

* Tue Sep 06 2016 Borne Mace <borne.mace@oracle.com> - 3.0.1-26.el7
- Added deploy action needed for kolla update (Borne Mace)  
- update test to use kottos_home instead of kolla_home (Steve Noyes)  
- move properties into zookeeper - phase 2 (Steve Noyes)  
- move properties into zookeeper - phase 2 (Steve Noyes)  
- update kollacli with latest kottos changes (Steve Noyes)  
- Remove no longer needed packages (six, paramiko) in cli v4 (Steve Noyes)  
- update rpm build spec for kollacli v4 (Steve Noyes)  
- removal of blaze code from cli (for v4) (Steve Noyes)

* Wed Aug 03 2016 Steve Noyes <steve.noyes@oracle.com> - 3.0.1-25.el7
- change plugin license back to gpl3 (Steve Noyes)  
- Added pep-484 entry to inventory file. (Borne Mace)  
- Added initial mypy / pep-484 type hinting support. (Borne Mace)

* Tue Jul 19 2016 Steve Noyes <steve.noyes@oracle.com> - 3.0.1-24.el7
- Properly display non-ascii chars in table output (Steve Noyes)

* Thu Jul 07 2016 Steve Noyes <steve.noyes@oracle.com> - 3.0.1-21.el7
- allow property set of empty string (Steve Noyes)

* Thu Jun 30 2016 Steve Noyes <steve.noyes@oracle.com> - 3.0.1-20.el7
- Better version spec for docker-py (Steve Noyes)

* Tue Jun 21 2016 Steve Noyes <steve.noyes@oracle.com> - 3.0.1-19.el7
- add api comment to api about locality of api objects (Steve Noyes)

* Wed Jun 15 2016 Steve Noyes <steve.noyes@oracle.com> - 3.0.1-18.el7
- change 'kolla' to 'root' when asking for password in host setup (Steve Noyes)

* Wed Jun 15 2016 Steve Noyes <steve.noyes@oracle.com> - 3.0.1-17.el7
- fix string pointer bug in last checkin (Steve Noyes)  
- fix string pointer bug in last checkin (Steve Noyes)

* Tue Jun 14 2016 Steve Noyes <steve.noyes@oracle.com> - 3.0.1-15.el7
- make ansible plugin message display more reliable (Steve Noyes)

* Thu Jun 09 2016 Steve Noyes <steve.noyes@oracle.com> - 3.0.1-14.el7
- update docs (Steve Noyes)  
- fix host & service associations in group object (Steve Noyes)  
- properly handle repeated params in group/service get (Steve Noyes)

* Thu Jun 02 2016 Steve Noyes <steve.noyes@oracle.com> - 3.0.1-13.el7
- add timeout option to deploy (Steve Noyes)

* Wed Jun 01 2016 Steve Noyes <steve.noyes@oracle.com> - 3.0.1-12.el7
- show error details on 'One or more items failed' (Steve Noyes)

* Fri May 27 2016 Steve Noyes <steve.noyes@oracle.com> - 3.0.1-11.el7
- various upgrade fixes (Steve Noyes)

* Fri May 27 2016 Steve Noyes <steve.noyes@oracle.com> - 3.0.1-10.el7
- Use inventory_samples for location of all-in-one file (Steve Noyes)

* Thu May 26 2016 Steve Noyes <steve.noyes@oracle.com> - 3.0.1-9.el7
- use all-in-one file to seed initial inventory (Steve Noyes)

* Mon May 23 2016 Steve Noyes <steve.noyes@oracle.com> - 3.0.1-8.el7
- use private ansible.cfg file (Steve Noyes)

* Mon May 23 2016 Steve Noyes <steve.noyes@oracle.com> - 3.0.1-7.el7
- add ability to enable plugin debug via /tmp file (Steve Noyes)

* Mon May 23 2016 Steve Noyes <steve.noyes@oracle.com> - 3.0.1-6.el7
- add version to api, misc fixes (Steve Noyes)  
- add warning on local deploy and avoid doc build errors on doc gen (Steve Noyes)

* Tue May 17 2016 James McCarthy <james.m.mccarthy@oracle.com> - 3.0.1-5.el7
- Updated pipeling setting in line with bug 23282017 (James McCarthy)

* Mon May 09 2016 Steve Noyes <steve.noyes@oracle.com> - 3.0.1-4.el7
- change order of chmod on create fifo (Steve Noyes)

* Fri May 06 2016 Steve Noyes <steve.noyes@oracle.com> - 3.0.1-3.el7
- move callback plugin pipe down a level in /tmp (Steve Noyes)

* Fri May 06 2016 Steve Noyes <steve.noyes@oracle.com> - 3.0.1-2.el7
- add ability to set debug logging as an env variable (Steve Noyes)

* Thu May 05 2016 - James McCarthy <james.m.mccarthy@oracle.com>
- Updated plugin_dir to be in line with paths in default file

* Fri Apr 29 2016 - Wiekus Beukes <wiekus.beukes@oracle.com>
- Updated the kolla-ansible requirement to 3.0.0

* Wed Apr 13 2016 - Steve Noyes <steve.noyes@oracle.com>
- add kolla-ansible-plugin subpackage
- suppress warning on egg removal
- remove etc and usr/share refs

* Thu Apr 07 2016 - Borne Mace <borne.mace@oracle.com>
- added ansible.lock file to coordinate ansible synchronization

* Thu Apr 07 2016 - Steve Noyes <steve.noyes@oracle.com>
- rename passwd_editor.py to kolla_actions.py

* Tue Apr 05 2016 - Steve Noyes <steve.noyes@oracle.com>
- remove obsolete pexpect requirement

* Tue Feb 23 2016 - Borne Mace <borne.mace@oracle.com>
- added clean up of old egg-info directories during update

* Tue Feb 23 2016 - Steve Noyes <steve.noyes@oracle.com>
- disable retry_files_enabled in ansible.cfg

* Thu Feb 11 2016 - Steve Noyes <steve.noyes@oracle.com>
- disallow pexpect 3.3 (sudo issue)
- remove obsolete oslo-utils reference

* Mon Oct 26 2015 - Steve Noyes <steve.noyes@oracle.com>
- Remove obsolete json_generator

* Fri Oct 02 2015 - Wiekus Beukes <wiekus.beukes@oracle.com>
- Allow user to precreate the ssh keys

* Thu Oct 01 2015 - Steve Noyes <steve.noyes@oracle.com>
- replace sudo command with runuser

* Fri Sep 25 2015 - Steve Noyes <steve.noyes@oracle.com>
- added sticky bits and acl to simplify logging permissions

* Thu Sep 24 2015 - Steve Noyes <steve.noyes@oracle.com>
- Added kolla log dir under /var/log/

* Thu Sep 17 2015 - Borne Mace <borne.mace@oracle.com>
- Added the ansible directory under /usr/share/kolla/kollacli
- Added code to copy the kollacli specific playbooks into that directory

* Wed Sep 16 2015 - Wiekus Beukes <wiekus.beukes@oracle.com>
- Added the bash completion setup
- Added code to augment the kolla sudo file for the password mgmt piece

* Tue Sep 08 2015 - Wiekus Beukes <wiekus.beukes@oracle.com>
- Updated dependencies
- Added the creation of an empty inventory file to fix the permissions
- Changed %config to %config(noreplace)

* Thu Sep 03 2015 - Wiekus Beukes <wiekus.beukes@oracle.com>
- Fixed day of week
- Fixed all the post issues

* Wed Sep 02 2015 - Wiekus Beukes <wiekus.beukes@oracle.com>
- Initial release

